summaryrefslogtreecommitdiff
path: root/jstests/replsets/libs/tenant_migration_test.js
diff options
context:
space:
mode:
Diffstat (limited to 'jstests/replsets/libs/tenant_migration_test.js')
-rw-r--r--jstests/replsets/libs/tenant_migration_test.js7
1 files changed, 6 insertions, 1 deletions
diff --git a/jstests/replsets/libs/tenant_migration_test.js b/jstests/replsets/libs/tenant_migration_test.js
index 84057636cc7..a810a8c889a 100644
--- a/jstests/replsets/libs/tenant_migration_test.js
+++ b/jstests/replsets/libs/tenant_migration_test.js
@@ -281,7 +281,8 @@ function TenantMigrationTest(
cmdObj, this.getDonorRst(), retryOnRetryableErrors);
// If the command succeeded, we expect that the migration is marked garbage collectable on
// the donor and the recipient. Check the state docs for expireAt.
if (res.ok) {
const donorPrimary = this.getDonorPrimary();
const recipientPrimary = this.getRecipientPrimary();
@@ -301,6 +302,10 @@ function TenantMigrationTest(
if (recipientStateDoc) {
assert(recipientStateDoc.expireAt);
}
+
+ const configDBCollections = recipientPrimary.getDB('config').getCollectionNames();
+ assert(!configDBCollections.includes('repl.migration.oplog_' + migrationIdString),
+ configDBCollections);
}
return res;
@@ -281,7 +281,8 @@ function TenantMigrationTest(
cmdObj, this.getDonorRst(), retryOnRetryableErrors);
// If the command succeeded, we expect that the migration is marked garbage collectable on
- // the donor and the recipient. Check the state docs for expireAt.
+ // the donor and the recipient. Check the state docs for expireAt, and check that the oplog
+ // buffer collection has been dropped.
if (res.ok) {
const donorPrimary = this.getDonorPrimary();